_**by Edgar Allan Poe**  
(published 1841)_

    

   THE mental features discoursed of as the analytical, are, in themselves, but little susceptible of analysis. We appreciate them only in their effects. We know of them, among other things, that they are always to their possessor, when inordinately possessed, a source of the liveliest enjoyment. As the strong man exults in his physical ability, delighting in such exercises as call his muscles into action, so glories the analyst in that moral activity which disentangles. He derives pleasure from even the most trivial occupations bringing his talent into play. He is fond of enigmas, of conundrums, of hieroglyphics; exhibiting in his solutions of each a degree of acumen which appears to the ordinary apprehension præternatural. His results, brought about by the very soul and essence of method, have, in truth, the whole air of intuition.  
  
    The faculty of re-solution is possibly much invigorated by mathematical study, and especially by that highest branch of it which, unjustly, and merely on account of its retrograde operations, has been called, as if par excellence, analysis. Yet to calculate is not in itself to analyse. A chess-player, for example, does the one without effort at the other. It follows that the game of chess, in its effects upon mental character, is greatly misunderstood. I am not now writing a treatise, but simply prefacing a somewhat peculiar narrative by observations very much at random; I will, therefore, take occasion to assert that the higher powers of the reflective intellect are more decidedly and more usefully tasked by the unostentatious game of draughts than by all the elaborate frivolity of chess. In this latter, where the pieces have different and bizarre motions, with various and variable values, what is only complex is mistaken (a not unusual error) for what is profound. The attention is here called powerfully into play. If it flag for an instant, an oversight is committed, resulting in injury or defeat. The possible moves being not only manifold but involute, the chances of such oversights are multiplied; and in nine cases out of ten it is the more concentrative rather than the more acute player who conquers. In draughts, on the contrary, where the moves are unique and have but little variation, the probabilities of inadvertence are diminished, and the mere attention being left comparatively unemployed, what advantages are obtained by either party are obtained by superior acumen. To be less abstract --Let us suppose a game of draughts where the pieces are reduced to four kings, and where, of course, no oversight is to be expected. It is obvious that here the victory can be decided (the players being at all equal) only by some recherche movement, the result of some strong exertion of the intellect. Deprived of ordinary resources, the analyst throws himself into the spirit of his opponent, identifies himself therewith, and not unfrequently sees thus, at a glance, the sole methods (sometimes indeed absurdly simple ones) by which he may seduce into error or hurry into miscalculation.  
  
    Whist has long been noted for its influence upon what is termed the calculating power; and men of the highest order of intellect have been known to take an apparently unaccountable delight in it, while eschewing chess as frivolous. Beyond doubt there is nothing of a similar nature so greatly tasking the faculty of analysis. The best chess-player in Christendom may be little more than the best player of chess; but proficiency in whist implies capacity for success in all those more important undertakings where mind struggles with mind. When I say proficiency, I mean that perfection in the game which includes a comprehension of all the sources whence legitimate advantage may be derived. These are not only manifold but multiform, and lie frequently among recesses of thought altogether inaccessible to the ordinary understanding. To observe attentively is to remember distinctly; and, so far, the concentrative chess-player will do very well at whist; while the rules of Hoyle (themselves based upon the mere mechanism of the game) are sufficiently and generally comprehensible. Thus to have a retentive memory, and to proceed by "the book," are points commonly regarded as the sum total of good playing. But it is in matters beyond the limits of mere rule that the skill of the analyst is evinced. He makes, in silence, a host of observations and inferences. So, perhaps, do his companions; and the difference in the extent of the information obtained, lies not so much in the validity of the inference as in the quality of the observation. The necessary knowledge is that of what to observe. Our player confines himself not at all; nor, because the game is the object, does he reject deductions from things external to the game. He examines the countenance of his partner, comparing it carefully with that of each of his opponents. He considers the mode of assorting the cards in each hand; often counting trump by trump, and honor by honor, through the glances bestowed by their holders upon each. He notes every variation of face as the play progresses, gathering a fund of thought from the differences in the expression of certainty, of surprise, of triumph, or of chagrin. From the manner of gathering up a trick he judges whether the person taking it can make another in the suit. He recognises what is played through feint, by the air with which it is thrown upon the table. A casual or inadvertent word; the accidental dropping or turning of a card, with the accompanying anxiety or carelessness in regard to its concealment; the counting of the tricks, with the order of their arrangement; embarrassment, hesitation, eagerness or trepidation --all afford, to his apparently intuitive perception, indications of the true state of affairs. The first two or three rounds having been played, he is in full possession of the contents of each hand, and thenceforward puts down his cards with as absolute a precision of purpose as if the rest of the party had turned outward the faces of their own.  
  
    The analytical power should not be confounded with simple ingenuity; for while the analyst is necessarily ingenious, the ingenious man is often remarkably incapable of analysis. The constructive or combining power, by which ingenuity is usually manifested, and to which the phrenologists (I believe erroneously) have assigned a separate organ, supposing it a primitive faculty, has been so frequently seen in those whose intellect bordered otherwise upon idiocy, as to have attracted general observation among writers on morals. Between ingenuity and the analytic ability there exists a difference far greater, indeed, than that between the fancy and the imagination, but of a character very strictly analogous. It will be found, in fact, that the ingenious are always fanciful, and the truly imaginative never otherwise than analytic.  
  
    The narrative which follows will appear to the reader somewhat in the light of a commentary upon the propositions just advanced.  
  
    Residing in Paris during the spring and part of the summer of 18--, I there became acquainted with a Monsieur C. Auguste Dupin. This young gentleman was of an excellent -- indeed of an illustrious family, but, by a variety of untoward events, had been reduced to such poverty that the energy of his character succumbed beneath it, and he ceased to bestir himself in the world, or to care for the retrieval of his fortunes. By courtesy of his creditors, there still remained in his possession a small remnant of his patrimony; and, upon the income arising from this, he managed, by means of a rigorous economy, to procure the necessaries of life, without troubling himself about its superfluities. Books, indeed, were his sole luxuries, and in Paris these are easily obtained.  
  
    Our first meeting was at an obscure library in the Rue Montmartre, where the accident of our both being in search of the same very rare and very remarkable volume, brought us into closer communion. We saw each other again and again. I was deeply interested in the little family history which he detailed to me with all that candor which a Frenchman indulges whenever mere self is his theme. I was astonished, too, at the vast extent of his reading; and, above all, I felt my soul enkindled within me by the wild fervor, and the vivid freshness of his imagination. Seeking in Paris the objects I then sought, I felt that the society of such a man would be to me a treasure beyond price; and this feeling I frankly confided to him. It was at length arranged that we should live together during my stay in the city; and as my worldly circumstances were somewhat less embarrassed than his own, I was permitted to be at the expense of renting, and furnishing in a style which suited the rather fantastic gloom of our common temper, a time-eaten and grotesque mansion, long deserted through superstitions into which we did not inquire, and tottering to its fall in a retired and desolate portion of the Faubourg St. Germain.  
  
    Had the routine of our life at this place been known to the world, we should have been regarded as madmen --although, perhaps, as madmen of a harmless nature. Our seclusion was perfect. We admitted no visitors. Indeed the locality of our retirement had been carefully kept a secret from my own former associates; and it had been many years since Dupin had ceased to know or be known in Paris. We existed within ourselves alone.  
  
    It was a freak of fancy in my friend (for what else shall I call it?) to be enamored of the Night for her own sake; and into this bizarrerie, as into all his others, I quietly fell; giving myself up to his wild whims with a perfect abandon. The sable divinity would not herself dwell with us always; but we could counterfeit her presence. At the first dawn of the morning we closed all the messy shutters of our old building; lighting a couple of tapers which, strongly perfumed, threw out only the ghastliest and feeblest of rays. By the aid of these we then busied our souls in dreams --reading, writing, or conversing, until warned by the clock of the advent of the true Darkness. Then we sallied forth into the streets, arm in arm, continuing the topics of the day, or roaming far and wide until a late hour, seeking, amid the wild lights and shadows of the populous city, that infinity of mental excitement which quiet observation can afford.  
  
    At such times I could not help remarking and admiring (although from his rich ideality I had been prepared to expect it) a peculiar analytic ability in Dupin. He seemed, too, to take an eager delight in its exercise --if not exactly in its display --and did not hesitate to confess the pleasure thus derived. He boasted to me, with a low chuckling laugh, that most men, in respect to himself, wore windows in their bosoms, and was wont to follow up such assertions by direct and very startling proofs of his intimate knowledge of my own. His manner at these moments was frigid and abstract; his eyes were vacant in expression; while his voice, usually a rich tenor, rose into a treble which would have sounded petulantly but for the deliberateness and entire distinctness of the enunciation. Observing him in these moods, I often dwelt meditatively upon the old philosophy of the Bi-Part Soul, and amused myself with the fancy of a double Dupin --the creative and the resolvent.  
  
    Let it not be supposed, from what I have just said, that I am detailing any mystery, or penning any romance. What I have described in the Frenchman, was merely the result of an excited, or perhaps of a diseased intelligence. But of the character of his remarks at the periods in question an example will best convey the idea.  
  
    We were strolling one night down a long dirty street, in the vicinity of the Palais Royal. Being both, apparently, occupied with thought, neither of us had spoken a syllable for fifteen minutes at least. All at once Dupin broke forth with these words:  
  
    "He is a very little fellow, that's true, and would do better for the Théâtre des Variétés."  
  
    "There can be no doubt of that," I replied unwittingly, and not at first observing (so much had I been absorbed in reflection) the extraordinary manner in which the speaker had chimed in with my meditations. In an instant afterward I recollected myself, and my astonishment was profound.  
  
    "Dupin," said I, gravely, "this is beyond my comprehension. I do not hesitate to say that I am amazed, and can scarcely credit my senses. How was it possible you should know I was thinking of ___ ?" Here I paused, to ascertain beyond a doubt whether he really knew of whom I thought.  
  
   ___ "of Chantilly," said he, "why do you pause? You were remarking to yourself that his diminutive figure unfitted him for tragedy."  
  
    This was precisely what had formed the subject of my reflections. Chantilly was a quondam cobbler of the Rue St. Denis, who, becoming stage-mad, had attempted the rôle of Xerxes, in Crébillon's tragedy so called, and been notoriously Pasquinaded for his pains.  
  
   "Tell me, for Heaven's sake," I exclaimed, "the method --if method there is --by which you have been enabled to fathom my soul in this matter." In fact I was even more startled than I would have been willing to express.  
  
   "It was the fruiterer," replied my friend, "who brought you to the conclusion that the mender of soles was not of sufficient height for Xerxes et id genus omne."  
  
   "The fruiterer! --you astonish me --I know no fruiterer whomsoever."  
  
   "The man who ran up against you as we entered the street --it may have been fifteen minutes ago."  
  
   I now remembered that, in fact, a fruiterer, carrying upon his head a large basket of apples, had nearly thrown me down, by accident, as we passed from the Rue C___  into the thoroughfare where we stood; but what this had to do with Chantilly I could not possibly understand.  
  
   There was not a particle of charlatanerie about Dupin. "I will explain," he said, "and that you may comprehend all clearly, we will first retrace the course of your meditations, from the moment in which I spoke to you until that of the rencontre with the fruiterer in question. The larger links of the chain run thus --Chantilly, Orion, Dr. Nichols, Epicurus, Stereotomy, the street stones, the fruiterer."  
  
   There are few persons who have not, at some period of their lives, amused themselves in retracing the steps by which particular conclusions of their own minds have been attained. The occupation is often full of interest; and he who attempts it for the first time is astonished by the apparently illimitable distance and incoherence between the starting-point and the goal. What, then, must have been my amazement when I heard the Frenchman speak what he had just spoken, and when I could not help acknowledging that he had spoken the truth. He continued:  
  
   "We had been talking of horses, if I remember aright, just before leaving the Rue C___. This was the last subject we discussed. As we crossed into this street, a fruiterer, with a large basket upon his head, brushing quickly past us, thrust you upon a pile of paving-stones collected at a spot where the causeway is undergoing repair. You stepped upon one of the loose fragments, slipped, slightly strained your ankle, appeared vexed or sulky, muttered a few words, turned to look at the pile, and then proceeded in silence. I was not particularly attentive to what you did; but observation has become with me, of late, a species of necessity.  
  
   "You kept your eyes upon the ground --glancing, with a petulant expression, at the holes and ruts in the pavement, (so that I saw you were still thinking of the stones,) until we reached the little alley called Lamartine, which has been paved, by way of experiment, with the overlapping and riveted blocks. Here your countenance brightened up, and, perceiving your lips move, I could not doubt that you murmured the word 'stereotomy,' a term very affectedly applied to this species of pavement. I knew that you could not say to yourself 'stereotomy' without being brought to think of atomies, and thus of the theories of Epicurus; and since, when we discussed this subject not very long ago, I mentioned to you how singularly, yet with how little notice, the vague guesses of that noble Greek had met with confirmation in the late nebular cosmogony, I felt that you could not avoid casting your eyes upward to the great nebula in Orion, and I certainly expected that you would do so. You did look up; and I was now assured that I had correctly followed your steps. But in that bitter tirade upon Chantilly, which appeared in yesterday's 'Musée,' the satirist, making some disgraceful allusions to the cobbler's change of name upon assuming the buskin, quoted a Latin line about which we have often conversed. I mean the line  
  
                                    Perdidit antiquum litera prima sonum  
  
I had told you that this was in reference to Orion, formerly written Urion; and, from certain pungencies connected with this explanation, I was aware that you could not have forgotten it. It was clear, therefore, that you would not fail to combine the two ideas of Orion and Chantilly. That you did combine them I saw by the character of the smile which passed over your lips. You thought of the poor cobbler's immolation. So far, you had been stooping in your gait; but now I saw you draw yourself up to your full height. I was then sure that you reflected upon the diminutive figure of Chantilly. At this point I interrupted your meditations to remark that as, in fact, he was a very little fellow --that Chantilly --he would do better at the Théâtre des Variétés."  
  
   Not long after this, we were looking over an evening edition of the "Gazette des Tribunaux," when the following paragraphs arrested our attention.  
  
   "EXTRAORDINARY MURDERS. --This morning, about three o'clock, the inhabitants of the Quartier St. Roch were aroused from sleep by a succession of terrific shrieks, issuing, apparently, from the fourth story of a house in the Rue Morgue, known to be in the sole occupancy of one Madame L'Espanaye, and her daughter, Mademoiselle Camille L'Espanaye. After some delay, occasioned by a fruitless attempt to procure admission in the usual manner, the gateway was broken in with a crowbar, and eight or ten of the neighbors entered, accompanied by two gendarmes. By this time the cries had ceased; but, as the party rushed up the first flight of stairs, two or more rough voices, in angry contention, were distinguished, and seemed to proceed from the upper part of the house. As the second landing was reached, these sounds, also, had ceased, and everything remained perfectly quiet. The party spread themselves, and hurried from room to room. Upon arriving at a large back chamber in the fourth story, (the door of which, being found locked, with the key inside, was forced open,) a spectacle presented itself which struck every one present not less with horror than with astonishment.  
  
   "The apartment was in the wildest disorder --the furniture broken and thrown about in all directions. There was only one bedstead; and from this the bed had been removed, and thrown into the middle of the floor. On a chair lay a razor, besmeared with blood. On the hearth were two or three long and thick tresses of grey human hair, also dabbled in blood, and seeming to have been pulled out by the roots. Upon the floor were found four Napoleons, an ear-ring of topaz, three large silver spoons, three smaller of métal d'Alger, and two bags, containing nearly four thousand francs in gold. The drawers of a bureau, which stood in one corner, were open, and had been, apparently, rifled, although many articles still remained in them. A small iron safe was discovered under the bed (not under the bedstead). It was open, with the key still in the door. It had no contents beyond a few old letters, and other papers of little consequence.  
  
   "Of Madame L'Espanaye no traces were here seen; but an unusual quantity of soot being observed in the fire-place, a search was made in the chimney, and (horrible to relate!) the corpse of the daughter, head downward, was dragged therefrom; it having been thus forced up the narrow aperture for a considerable distance. The body was quite warm. Upon examining it, many excoriations were perceived, no doubt occasioned by the violence with which it had been thrust up and disengaged. Upon the face were many severe scratches, and, upon the throat, dark bruises, and deep indentations of finger nails, as if the deceased had been throttled to death.  
  
   "After a thorough investigation of every portion of the house, without farther discovery, the party made its way into a small paved yard in the rear of the building, where lay the corpse of the old lady, with her throat so entirely cut that, upon an attempt to raise her, the head fell off. The body, as well as the head, was fearfully mutilated --the former so much so as scarcely to retain any semblance of humanity.  
  
   "To this horrible mystery there is not as yet, we believe, the slightest clew."  
  
   The next day's paper had these additional particulars.  
  
   "The Tragedy in the Rue Morgue. Many individuals have been examined in relation to this most extraordinary and frightful affair." [The word 'affaire' has not yet, in France, that levity of import which it conveys with us,] "but nothing whatever has transpired to throw light upon it. We give below all the material testimony elicited.  
  
   "Pauline Dubourg, laundress, deposes that she has known both the deceased for three years, having washed for them during that period. The old lady and her daughter seemed on good terms --very affectionate towards each other. They were excellent pay. Could not speak in regard to their mode or means of living. Believed that Madame L. told fortunes for a living. Was reputed to have money put by. Never met any persons in the house when she called for the clothes or took them home. Was sure that they had no servant in employ. There appeared to be no furniture in any part of the building except in the fourth story.  
  
   "Pierre Moreau, tobacconist, deposes that he has been in the habit of selling small quantities of tobacco and snuff to Madame L'Espanaye for nearly four years. Was born in the neighborhood, and has always resided there. The deceased and her daughter had occupied the house in which the corpses were found, for more than six years. It was formerly occupied by a jeweller, who under-let the upper rooms to various persons. The house was the property of Madame L. She became dissatisfied with the abuse of the premises by her tenant, and moved into them herself, refusing to let any portion. The old lady was childish. Witness had seen the daughter some five or six times during the six years. The two lived an exceedingly retired life --were reputed to have money. Had heard it said among the neighbors that Madame L. told fortunes --did not believe it. Had never seen any person enter the door except the old lady and her daughter, a porter once or twice, and a physician some eight or ten times.  
  
   "Many other persons, neighbors, gave evidence to the same effect. No one was spoken of as frequenting the house. It was not known whether there were any living connexions of Madame L. and her daughter. The shutters of the front windows were seldom opened. Those in the rear were always closed, with the exception of the large back room, fourth story. The house was a good house --not very old.  
  
   "Isidore Musèt, gendarme, deposes that he was called to the house about three o'clock in the morning, and found some twenty or thirty persons at the gateway, endeavoring to gain admittance. Forced it open, at length, with a bayonet --not with a crowbar. Had but little difficulty in getting it open, on account of its being a double or folding gate, and bolted neither at bottom nor top. The shrieks were continued until the gate was forced --and then suddenly ceased. They seemed to be screams of some person (or persons) in great agony --were loud and drawn out, not short and quick. Witness led the way up stairs. Upon reaching the first landing, heard two voices in loud and angry contention --the one a gruff voice, the other much shriller --a very strange voice. Could distinguish some words of the former, which was that of a Frenchman. Was positive that it was not a woman's voice. Could distinguish the words 'sacré' and 'diable.' The shrill voice was that of a foreigner. Could not be sure whether it was the voice of a man or of a woman. Could not make out what was said, but believed the language to be Spanish. The state of the room and of the bodies was described by this witness as we described them yesterday.  
  
   "Henri Duval, a neighbor, and by trade a silver-smith, deposes that he was one of the party who first entered the house. Corroborates the testimony of Musèt in general. As soon as they forced an entrance, they reclosed the door, to keep out the crowd, which collected very fast, notwithstanding the lateness of the hour. The shrill voice, this witness thinks, was that of an Italian. Was certain it was not French. Could not be sure that it was a man's voice. It might have been a woman's. Was not acquainted with the Italian language. Could not distinguish the words, but was convinced by the intonation that the speaker was an Italian. Knew Madame L. and her daughter. Had conversed with both frequently. Was sure that the shrill voice was not that of either of the deceased.  
  
   "___ Odenheimer, restaurateur. This witness volunteered his testimony. Not speaking French, was examined through an interpreter. Is a native of Amsterdam. Was passing the house at the time of the shrieks. They lasted for several minutes --probably ten. They were long and loud --very awful and distressing. Was one of those who entered the building. Corroborated the previous evidence in every respect but one. Was sure that the shrill voice was that of a man --of a Frenchman. Could not distinguish the words uttered. They were loud and quick --unequal --spoken apparently in fear as well as in anger. The voice was harsh --not so much shrill as harsh. Could not call it a shrill voice. The gruff voice said repeatedly 'sacré,' 'diable,' and once 'mon Dieu.'  
  
   "Jules Mignaud, banker, of the firm of Mignaud et Fils, Rue Deloraine. Is the elder Mignaud. Madame L'Espanaye had some property. Had opened an account with his banking house in the spring of the year ---- (eight years previously). Made frequent deposits in small sums. Had checked for nothing until the third day before her death, when she took out in person the sum of 4000 francs. This sum was paid in gold, and a clerk went home with the money.  
  
   "Adolphe Le Bon, clerk to Mignaud et Fils, deposes that on the day in question, about noon, he accompanied Madame L'Espanaye to her residence with the 4000 francs, put up in two bags. Upon the door being opened, Mademoiselle L. appeared and took from his hands one of the bags, while the old lady relieved him of the other. He then bowed and departed. Did not see any person in the street at the time. It is a bye-street --very lonely.  
  
   "William Bird, tailor deposes that he was one of the party who entered the house. Is an Englishman. Has lived in Paris two years. Was one of the first to ascend the stairs. Heard the voices in contention. The gruff voice was that of a Frenchman. Could make out several words, but cannot now remember all. Heard distinctly 'sacré' and 'mon Dieu.' There was a sound at the moment as if of several persons struggling --a scraping and scuffling sound. The shrill voice was very loud --louder than the gruff one. Is sure that it was not the voice of an Englishman. Appeared to be that of a German. Might have been a woman's voice. Does not understand German.  
  
   "Four of the above-named witnesses, being recalled, deposed that the door of the chamber in which was found the body of Mademoiselle L. was locked on the inside when the party reached it. Every thing was perfectly silent --no groans or noises of any kind. Upon forcing the door no person was seen. The windows, both of the back and front room, were down and firmly fastened from within. A door between the two rooms was closed, but not locked. The door leading from the front room into the passage was locked, with the key on the inside. A small room in the front of the house, on the fourth story, at the head of the passage, was open, the door being ajar. This room was crowded with old beds, boxes, and so forth. These were carefully removed and searched. There was not an inch of any portion of the house which was not carefully searched. Sweeps were sent up and down the chimneys. The house was a four story one, with garrets (mansardes.) A trap-door on the roof was nailed down very securely --did not appear to have been opened for years. The time elapsing between the hearing of the voices in contention and the breaking open of the room door, was variously stated by the witnesses. Some made it as short as three minutes --some as long as five. The door was opened with difficulty.  
  
   "Alfonzo Garcio, undertaker, deposes that he resides in the Rue Morgue. Is a native of Spain. Was one of the party who entered the house. Did not proceed up stairs. Is nervous, and was apprehensive of the consequences of agitation. Heard the voices in contention. The gruff voice was that of a Frenchman. Could not distinguish what was said. The shrill voice was that of an Englishman --is sure of this. Does not understand the English language, but judges by the intonation.  
  
   "Alberto Montani, confectioner, deposes that he was among the first to ascend the stairs. Heard the voices in question. The gruff voice was that of a Frenchman. Distinguished several words. The speaker appeared to be expostulating. Could not make out the words of the shrill voice. Spoke quick and unevenly. Thinks it the voice of a Russian. Corroborates the general testimony. Is an Italian. Never conversed with a native of Russia.  
  
   "Several witnesses, recalled, here testified that the chimneys of all the rooms on the fourth story were too narrow to admit the passage of a human being. By 'sweeps' were meant cylindrical sweeping-brushes, such as are employed by those who clean chimneys. These brushes were passed up and down every flue in the house. There is no back passage by which any one could have descended while the party proceeded up stairs. The body of Mademoiselle L'Espanaye was so firmly wedged in the chimney that it could not be got down until four or five of the party united their strength.  
  
   "Paul Dumas, physician, deposes that he was called to view the bodies about day-break. They were both then lying on the sacking of the bedstead in the chamber where Mademoiselle L. was found. The corpse of the young lady was much bruised and excoriated. The fact that it had been thrust up the chimney would sufficiently account for these appearances. The throat was greatly chafed. There were several deep scratches just below the chin, together with a series of livid spots which were evidently the impression of fingers. The face was fearfully discolored, and the eye-balls protruded. The tongue had been partially bitten through. A large bruise was discovered upon the pit of the stomach, produced, apparently, by the pressure of a knee. In the opinion of M. Dumas, Mademoiselle L'Espanaye had been throttled to death by some person or persons unknown. The corpse of the mother was horribly mutilated. All the bones of the right leg and arm were more or less shattered. The left tibia much splintered, as well as all the ribs of the left side. Whole body dreadfully bruised and discolored. It was not possible to say how the injuries had been inflicted. A heavy club of wood, or a broad bar of iron --a chair -- any large, heavy, and obtuse weapon would have produced such results, if wielded by the hands of a very powerful man. No woman could have inflicted the blows with any weapon. The head of the deceased, when seen by witness, was entirely separated from the body, and was also greatly shattered. The throat had evidently been cut with some very sharp instrument --probably with a razor.  
  
   "Alexandre Etienne, surgeon, was called with M. Dumas to view the bodies. Corroborated the testimony, and the opinions of M. Dumas.  
  
   "Nothing farther of importance was elicited, although several other persons were examined. A murder so mysterious, and so perplexing in all its particulars, was never before committed in Paris --if indeed a murder has been committed at all. The police are entirely at fault --an unusual occurrence in affairs of this nature. There is not, however, the shadow of a clew apparent."  
  
   The evening edition of the paper stated that the greatest excitement still continued in the Quartier St. Roch --that the premises in question had been carefully re-searched, and fresh examinations of witnesses instituted, but all to no purpose. A postscript, however, mentioned that Adolphe Le Bon had been arrested and imprisoned --although nothing appeared to criminate him, beyond the facts already detailed.  
  
   Dupin seemed singularly interested in the progress of this affair --at least so I judged from his manner, for he made no comments. It was only after the announcement that Le Bon had been imprisoned, that he asked me my opinion respecting the murders.  
  
   I could merely agree with all Paris in considering them an insoluble mystery. I saw no means by which it would be possible to trace the murderer.  
  
   "We must not judge of the means," said Dupin, "by this shell of an examination. The Parisian police, so much extolled for acumen, are cunning, but no more. There is no method in their proceedings, beyond the method of the moment. They make a vast parade of measures; but, not unfrequently, these are so ill adapted to the objects proposed, as to put us in mind of Monsieur Jourdain's calling for his robe-de-chambre --pour mieux entendre la musique. The results attained by them are not unfrequently surprising, but, for the most part, are brought about by simple diligence and activity. When these qualities are unavailing, their schemes fail. Vidocq, for example, was a good guesser, and a persevering man. But, without educated thought, he erred continually by the very intensity of his investigations. He impaired his vision by holding the object too close. He might see, perhaps, one or two points with unusual clearness, but in so doing he, necessarily, lost sight of the matter as a whole. Thus there is such a thing as being too profound. Truth is not always in a well. In fact, as regards the more important knowledge, I do believe that she is invariably superficial. The depth lies in the valleys where we seek her, and not upon the mountain-tops where she is found. The modes and sources of this kind of error are well typified in the contemplation of the heavenly bodies. To look at a star by glances --to view it in a side-long way, by turning toward it the exterior portions of the retina (more susceptible of feeble impressions of light than the interior), is to behold the star distinctly -- is to have the best appreciation of its lustre --a lustre which grows dim just in proportion as we turn our vision fully upon it. A greater number of rays actually fall upon the eye in the latter case, but, in the former, there is the more refined capacity for comprehension. By undue profundity we perplex and enfeeble thought; and it is possible to make even Venus herself vanish from the firmanent by a scrutiny too sustained, too concentrated, or too direct.  
  
   "As for these murders, let us enter into some examinations for ourselves, before we make up an opinion respecting them. An inquiry will afford us amusement," (I thought this an odd term, so applied, but said nothing) "and, besides, Le Bon once rendered me a service for which I am not ungrateful. We will go and see the premises with our own eyes. I know G___, the Prefect of Police, and shall have no difficulty in obtaining the necessary permission."  
  
   The permission was obtained, and we proceeded at once to the Rue Morgue. This is one of those miserable thoroughfares which intervene between the Rue Richelieu and the Rue St. Roch. It was late in the afternoon when we reached it; as this quarter is at a great distance from that in which we resided. The house was readily found; for there were still many persons gazing up at the closed shutters, with an objectless curiosity, from the opposite side of the way. It was an ordinary Parisian house, with a gateway, on one side of which was a glazed watch-box, with a sliding panel in the window, indicating a loge de concierge. Before going in we walked up the street, turned down an alley, and then, again turning, passed in the rear of the building --Dupin, meanwhile, examining the whole neighborhood, as well as the house, with a minuteness of attention for which I could see no possible object.  
  
   Retracing our steps, we came again to the front of the dwelling, rang, and, having shown our credentials, were admitted by the agents in charge. We went up stairs --into the chamber where the body of Mademoiselle L'Espanaye had been found, and where both the deceased still lay. The disorders of the room had, as usual, been suffered to exist. I saw nothing beyond what had been stated in the "Gazette des Tribunaux." Dupin scrutinized every thing --not excepting the bodies of the victims. We then went into the other rooms, and into the yard; a gendarme accompanying us throughout. The examination occupied us until dark, when we took our departure. On our way home my companion stepped in for a moment at the office of one of the daily papers.  
  
  
   I have said that the whims of my friend were manifold, and that Je les ménagais: --for this phrase there is no English equivalent. It was his humor, now, to decline all conversation on the subject of the murder, until about noon the next day. He then asked me, suddenly, if I had observed any thing peculiar at the scene of the atrocity.  
  
   There was something in his manner of emphasizing the word "peculiar," which caused me to shudder, without knowing why.  
  
   "No, nothing peculiar," I said; "nothing more, at least, than we both saw stated in the paper."  
  
   "The 'Gazette,' " he replied, "has not entered, I fear, into the unusual horror of the thing. But dismiss the idle opinions of this print. It appears to me that this mystery is considered insoluble, for the very reason which should cause it to be regarded as easy of solution --I mean for the outré character of its features. The police are confounded by the seeming absence of motive --not for the murder itself --but for the atrocity of the murder. They are puzzled, too, by the seeming impossibility of reconciling the voices heard in contention, with the facts that no one was discovered up stairs but the assassinated Mademoiselle L'Espanaye, and that there were no means of egress without the notice of the party ascending. The wild disorder of the room; the corpse thrust, with the head downward, up the chimney; the frightful mutilation of the body of the old lady; these considerations, with those just mentioned, and others which I need not mention, have sufficed to paralyze the powers, by putting completely at fault the boasted acumen, of the government agents. They have fallen into the gross but common error of confounding the unusual with the abstruse. But it is by these deviations from the plane of the ordinary, that reason feels its way, if at all, in its search for the true. In investigations such as we are now pursuing, it should not be so much asked 'what has occurred,' as 'what has occurred that has never occurred before.' In fact, the facility with which I shall arrive, or have arrived, at the solution of this mystery, is in the direct ratio of its apparent insolubility in the eyes of the police."  
  
   I stared at the speaker in mute astonishment.  
  
   "I am now awaiting," continued he, looking toward the door of our apartment --"I am now awaiting a person who, although perhaps not the perpetrator of these butcheries, must have been in some measure implicated in their perpetration. Of the worst portion of the crimes committed, it is probable that he is innocent. I hope that I am right in this supposition; for upon it I build my expectation of reading the entire riddle. I look for the man here --in this room --every moment. It is true that he may not arrive; but the probability is that he will. Should he come, it will be necessary to detain him. Here are pistols; and we both know how to use them when occasion demands their use."  
  
   I took the pistols, scarcely knowing what I did, or believing what I heard, while Dupin went on, very much as if in a soliloquy. I have already spoken of his abstract manner at such times. His discourse was addressed to myself; but his voice, although by no means loud, had that intonation which is commonly employed in speaking to some one at a great distance. His eyes, vacant in expression, regarded only the wall.  
  
   "That the voices heard in contention," he said, "by the party upon the stairs, were not the voices of the women themselves, was fully proved by the evidence. This relieves us of all doubt upon the question whether the old lady could have first destroyed the daughter, and afterward have committed suicide. I speak of this point chiefly for the sake of method; for the strength of Madame L'Espanaye would have been utterly unequal to the task of thrusting her daughter's corpse up the chimney as it was found; and the nature of the wounds upon her own person entirely preclude the idea of self-destruction. Murder, then, has been committed by some third party; and the voices of this third party were those heard in contention. Let me now advert --not to the whole testimony respecting these voices --but to what was peculiar in that testimony. Did you observe any thing peculiar about it?"  
  
   I remarked that, while all the witnesses agreed in supposing the gruff voice to be that of a Frenchman, there was much disagreement in regard to the shrill, or, as one individual termed it, the harsh voice.  
  
   "That was the evidence itself," said Dupin, "but it was not the peculiarity of the evidence. You have observed nothing distinctive. Yet there was something to be observed. The witnesses, as you remark, agreed about the gruff voice; they were here unanimous. But in regard to the shrill voice, the peculiarity is --not that they disagreed --but that, while an Italian, an Englishman, a Spaniard, a Hollander, and a Frenchman attempted to describe it, each one spoke of it as that of a foreigner. Each is sure that it was not the voice of one of his own countrymen. Each likens it --not to the voice of an individual of any nation with whose language he is conversant --but the converse. The Frenchman supposes it the voice of a Spaniard, and 'might have distinguished some words had he been acquainted with the Spanish.' The Dutchman maintains it to have been that of a Frenchman; but we find it stated that 'not understanding French this witness was examined through an interpreter.' The Englishman thinks it the voice of a German, and 'does not understand German.' The Spaniard 'is sure' that it was that of an Englishman, but 'judges by the intonation' altogether, 'as he has no knowledge of the English.' The Italian believes it the voice of a Russian, but 'has never conversed with a native of Russia.' A second Frenchman differs, moreover, with the first, and is positive that the voice was that of an Italian; but, not being cognizant of that tongue, is, like the Spaniard, 'convinced by the intonation.' Now, how strangely unusual must that voice have really been, about which such testimony as this could have been elicited! --in whose tones, even, denizens of the five great divisions of Europe could recognise nothing familiar! You will say that it might have been the voice of an Asiatic --of an African. Neither Asiatics nor Africans abound in Paris; but, without denying the inference, I will now merely call your attention to three points. The voice is termed by one witness 'harsh rather than shrill.' It is represented by two others to have been 'quick and unequal.' No words --no sounds resembling words --were by any witness mentioned as distinguishable.  
  
   "I know not," continued Dupin, "what impression I may have made, so far, upon your own understanding; but I do not hesitate to say that legitimate deductions even from this portion of the testimony --the portion respecting the gruff and shrill voices --are in themselves sufficient to engender a suspicion which should give direction to all farther progress in the investigation of the mystery. I said 'legitimate deductions;' but my meaning is not thus fully expressed. I designed to imply that the deductions are the sole proper ones, and that the suspicion arises inevitably from them as the single result. What the suspicion is, however, I will not say just yet. I merely wish you to bear in mind that, with myself, it was sufficiently forcible to give a definite form --a certain tendency --to my inquiries in the chamber.  
  
   "Let us now transport ourselves, in fancy, to this chamber. What shall we first seek here? The means of egress employed by the murderers. It is not too much to say that neither of us believe in praeternatural events. Madame and Mademoiselle L'Espanaye were not destroyed by spirits. The doers of the deed were material, and escaped materially. Then how? Fortunately, there is but one mode of reasoning upon the point, and that mode must lead us to a definite decision. --Let us examine, each by each, the possible means of egress. It is clear that the assassins were in the room where Mademoiselle L'Espanaye was found, or at least in the room adjoining, when the party ascended the stairs. It is then only from these two apartments that we have to seek issues. The police have laid bare the floors, the ceilings, and the masonry of the walls, in every direction. No secret issues could have escaped their vigilance. But, not trusting to their eyes, I examined with my own. There were, then, no secret issues. Both doors leading from the rooms into the passage were securely locked, with the keys inside. Let us turn to the chimneys. These, although of ordinary width for some eight or ten feet above the hearths, will not admit, throughout their extent, the body of a large cat. The impossibility of egress, by means already stated, being thus absolute, we are reduced to the windows. Through those of the front room no one could have escaped without notice from the crowd in the street. The murderers must have passed, then, through those of the back room. Now, brought to this conclusion in so unequivocal a manner as we are, it is not our part, as reasoners, to reject it on account of apparent impossibilities. It is only left for us to prove that these apparent 'impossibilities' are, in reality, not such.  
  
   "There are two windows in the chamber. One of them is unobstructed by furniture, and is wholly visible. The lower portion of the other is hidden from view by the head of the unwieldy bedstead which is thrust close up against it. The former was found securely fastened from within. It resisted the utmost force of those who endeavored to raise it. A large gimlet-hole had been pierced in its frame to the left, and a very stout nail was found fitted therein, nearly to the head. Upon examining the other window, a similar nail was seen similarly fitted in it; and a vigorous attempt to raise this sash, failed also. The police were now entirely satisfied that egress had not been in these directions. And, therefore, it was thought a matter of supererogation to withdraw the nails and open the windows.  
  
   "My own examination was somewhat more particular, and was so for the reason I have just given --because here it was, I knew, that all apparent impossibilities must be proved to be not such in reality.  
  
   "I proceeded to think thus --à posteriori. The murderers did escape from one of these windows. This being so, they could not have re-fastened the sashes from the inside, as they were found fastened; --the consideration which put a stop, through its obviousness, to the scrutiny of the police in this quarter. Yet the sashes were fastened. They must, then, have the power of fastening themselves. There was no escape from this conclusion. I stepped to the unobstructed casement, withdrew the nail with some difficulty, and attempted to raise the sash. It resisted all my efforts, as I had anticipated. A concealed spring must, I now knew, exist; and this corroboration of my idea convinced me that my premises, at least, were correct, however mysterious still appeared the circumstances attending the nails. A careful search soon brought to light the hidden spring. I pressed it, and, satisfied with the discovery, forbore to upraise the sash.  
  
   "I now replaced the nail and regarded it attentively. A person passing out through this window might have reclosed it, and the spring would have caught --but the nail could not have been replaced. The conclusion was plain, and again narrowed in the field of my investigations. The assassins must have escaped through the other window. Supposing, then, the springs upon each sash to be the same, as was probable, there must be found a difference between the nails, or at least between the modes of their fixture. Getting upon the sacking of the bedstead, I looked over the head-board minutely at the second casement. Passing my hand down behind the board, I readily discovered and pressed the spring, which was, as I had supposed, identical in character with its neighbor. I now looked at the nail. It was as stout as the other, and apparently fitted in the same manner --driven in nearly up to the head.  
  
   "You will say that I was puzzled; but, if you think so, you must have misunderstood the nature of the inductions. To use a sporting phrase, I had not been once 'at fault.' The scent had never for an instant been lost. There was no flaw in any link of the chain. I had traced the secret to its ultimate result, --and that result was the nail. It had, I say, in every respect, the appearance of its fellow in the other window; but this fact was an absolute nullity (conclusive as it might seem to be) when compared with the consideration that here, at this point, terminated the clew. 'There must be something wrong,' I said, 'about the nail.' I touched it; and the head, with about a quarter of an inch of the shank, came off in my fingers. The rest of the shank was in the gimlet-hole, where it had been broken off. The fracture was an old one (for its edges were incrusted with rust), and had apparently been accomplished by the blow of a hammer, which had partially imbedded, in the top of the bottom sash, the head portion of the nail. I now carefully replaced this head portion in the indentation whence I had taken it, and the resemblance to a perfect nail was complete -- the fissure was invisible. Pressing the spring, I gently raised the sash for a few inches; the head went up with it, remaining firm in its bed. I closed the window, and the semblance of the whole nail was again perfect.  
  
   "The riddle, so far, was now unriddled. The assassin had escaped through the window which looked upon the bed. Dropping of its own accord upon his exit (or perhaps purposely closed), it had become fastened by the spring; and it was the retention of this spring which had been mistaken by the police for that of the nail, --farther inquiry being thus considered unnecessary.  
  
   "The next question is that of the mode of descent. Upon this point I had been satisfied in my walk with you around the building. About five feet and a half from the casement in question there runs a lightning-rod. From this rod it would have been impossible for any one to reach the window itself, to say nothing of entering it. I observed, however, that the shutters of the fourth story were of the peculiar kind called by Parisian carpenters ferrades --a kind rarely employed at the present day, but frequently seen upon very old mansions at Lyons and Bourdeaux. They are in the form of an ordinary door, (a single, not a folding door) except that the lower half is latticed or worked in open trellis --thus affording an excellent hold for the hands. In the present instance these shutters are fully three feet and a half broad. When we saw them from the rear of the house, they were both about half open --that is to say, they stood off at right angles from the wall. It is probable that the police, as well as myself, examined the back of the tenement; but, if so, in looking at these ferrades in the line of their breadth (as they must have done), they did not perceive this great breadth itself, or, at all events, failed to take it into due consideration. In fact, having once satisfied themselves that no egress could have been made in this quarter, they would naturally bestow here a very cursory examination. It was clear to me, however, that the shutter belonging to the window at the head of the bed, would, if swung fully back to the wall, reach to within two feet of the lightning-rod. It was also evident that, by exertion of a very unusual degree of activity and courage, an entrance into the window, from the rod, might have been thus effected. --By reaching to the distance of two feet and a half (we now suppose the shutter open to its whole extent) a robber might have taken a firm grasp upon the trellis-work. Letting go, then, his hold upon the rod, placing his feet securely against the wall, and springing boldly from it, he might have swung the shutter so as to close it, and, if we imagine the window open at the time, might even have swung himself into the room.  
  
   "I wish you to bear especially in mind that I have spoken of a very unusual degree of activity as requisite to success in so hazardous and so difficult a feat. It is my design to show you, first, that the thing might possibly have been accomplished: --but, secondly and chiefly, I wish to impress upon your understanding the very extraordinary --the almost præternatural character of that agility which could have accomplished it.  
  
   "You will say, no doubt, using the language of the law, that 'to make out my case,' I should rather undervalue, than insist upon a full estimation of the activity required in this matter. This may be the practice in law, but it is not the usage of reason. My ultimate object is only the truth. My immediate purpose is to lead you to place in juxta-position, that very unusual activity of which I have just spoken, with that very peculiar shrill (or harsh) and unequal voice, about whose nationality no two persons could be found to agree, and in whose utterance no syllabification could be detected."  
  
   At these words a vague and half-formed conception of the meaning of Dupin flitted over my mind. I seemed to be upon the verge of comprehension, without power to comprehend --as men, at times, find themselves upon the brink of remembrance, without being able, in the end, to remember. My friend went on with his discourse.  
  
   "You will see," he said, "that I have shifted the question from the mode of egress to that of ingress. It was my design to convey the idea that both were effected in the same manner, at the same point. Let us now revert to the interior of the room. Let us survey the appearances here. The drawers of the bureau, it is said, had been rifled, although many articles of apparel still remained within them. The conclusion here is absurd. It is a mere guess --a very silly one --and no more. How are we to know that the articles found in the drawers were not all these drawers had originally contained? Madame L'Espanaye and her daughter lived an exceedingly retired life --saw no company --seldom went out --had little use for numerous changes of habiliment. Those found were at least of as good quality as any likely to be possessed by these ladies. If a thief had taken any, why did he not take the best --why did he not take all? In a word, why did he abandon four thousand francs in gold to encumber himself with a bundle of linen? The gold was abandoned. Nearly the whole sum mentioned by Monsieur Mignaud, the banker, was discovered, in bags, upon the floor. I wish you, therefore, to discard from your thoughts the blundering idea of motive, engendered in the brains of the police by that portion of the evidence which speaks of money delivered at the door of the house. Coincidences ten times as remarkable as this (the delivery of the money, and murder committed within three days upon the party receiving it), happen to all of us every hour of our lives, without attracting even momentary notice. Coincidences, in general, are great stumbling-blocks in the way of that class of thinkers who have been educated to know nothing of the theory of probabilities -- that theory to which the most glorious objects of human research are indebted for the most glorious of illustration. In the present instance, had the gold been gone, the fact of its delivery three days before would have formed something more than a coincidence. It would have been corroborative of this idea of motive. But, under the real circumstances of the case, if we are to suppose gold the motive of this outrage, we must also imagine the perpetrator so vacillating an idiot as to have abandoned his gold and his motive together.  
  
   "Keeping now steadily in mind the points to which I have drawn your attention --that peculiar voice, that unusual agility, and that startling absence of motive in a murder so singularly atrocious as this --let us glance at the butchery itself. Here is a woman strangled to death by manual strength, and thrust up a chimney, head downward. Ordinary assassins employ no such modes of murder as this. Least of all, do they thus dispose of the murdered. In the manner of thrusting the corpse up the chimney, you will admit that there was something excessively outré --something altogether irreconcilable with our common notions of human action, even when we suppose the actors the most depraved of men. Think, too, how great must have been that strength which could have thrust the body up such an aperture so forcibly that the united vigor of several persons was found barely sufficient to drag it down!  
  
   "Turn, now, to other indications of the employment of a vigor most marvellous. On the hearth were thick tresses --very thick tresses --of grey human hair. These had been torn out by the roots. You are aware of the great force necessary in tearing thus from the head even twenty or thirty hairs together. You saw the locks in question as well as myself. Their roots (a hideous sight!) were clotted with fragments of the flesh of the scalp --sure token of the prodigious power which had been exerted in uprooting perhaps half a million of hairs at a time. The throat of the old lady was not merely cut, but the head absolutely severed from the body: the instrument was a mere razor. I wish you also to look at the brutal ferocity of these deeds. Of the bruises upon the body of Madame L'Espanaye I do not speak. Monsieur Dumas, and his worthy coadjutor Monsieur Etienne, have pronounced that they were inflicted by some obtuse instrument; and so far these gentlemen are very correct. The obtuse instrument was clearly the stone pavement in the yard, upon which the victim had fallen from the window which looked in upon the bed. This idea, however simple it may now seem, escaped the police for the same reason that the breadth of the shutters escaped them --because, by the affair of the nails, their perceptions had been hermetically sealed against the possibility of the windows having ever been opened at all.  
  
   "If now, in addition to all these things, you have properly reflected upon the odd disorder of the chamber, we have gone so far as to combine the ideas of an agility astounding, a strength superhuman, a ferocity brutal, a butchery without motive, a grotesquerie in horror absolutely alien from humanity, and a voice foreign in tone to the ears of men of many nations, and devoid of all distinct or intelligible syllabification. What result, then, has ensued? What impression have I made upon your fancy?"  
  
   I felt a creeping of the flesh as Dupin asked me the question. "A madman," I said, "has done this deed --some raving maniac, escaped from a neighboring Maison de Santé."  
  
   "In some respects," he replied, "your idea is not irrelevant. But the voices of madmen, even in their wildest paroxysms, are never found to tally with that peculiar voice heard upon the stairs. Madmen are of some nation, and their language, however incoherent in its words, has always the coherence of syllabification. Besides, the hair of a madman is not such as I now hold in my hand. I disentangled this little tuft from the rigidly clutched fingers of Madame L'Espanaye. Tell me what you can make of it."  
  
   "Dupin!" I said, completely unnerved; "this hair is most unusual --this is no human hair."  
  
   "I have not asserted that it is," said he; "but, before we decide this point, I wish you to glance at the little sketch I have here traced upon this paper. It is a fac-simile drawing of what has been described in one portion of the testimony as 'dark bruises, and deep indentations of finger nails,' upon the throat of Mademoiselle L'Espanaye, and in another, (by Messrs. Dumas and Etienne,) as a 'series of livid spots, evidently the impression of fingers.'  
  
   "You will perceive," continued my friend, spreading out the paper upon the table before us, "that this drawing gives the idea of a firm and fixed hold. There is no slipping apparent. Each finger has retained --possibly until the death of the victim --the fearful grasp by which it originally imbedded itself. Attempt, now, to place all your fingers, at the same time, in the respective impressions as you see them."  
  
   I made the attempt in vain.  
  
   "We are possibly not giving this matter a fair trial," he said. "The paper is spread out upon a plane surface; but the human throat is cylindrical. Here is a billet of wood, the circumference of which is about that of the throat. Wrap the drawing around it, and try the experiment again."  
  
   I did so; but the difficulty was even more obvious than before. "This," I said, "is the mark of no human hand."  
  
   "Read now," replied Dupin, "this passage from Cuvier."  
  
   It was a minute anatomical and generally descriptive account of the large fulvous Ourang-Outang of the East Indian Islands. The gigantic stature, the prodigious strength and activity, the wild ferocity, and the imitative propensities of these mammalia are sufficiently well known to all. I understood the full horrors of the murder at once.  
  
   "The description of the digits," said I, as I made an end of reading, "is in exact accordance with this drawing. I see that no animal but an Ourang-Outang, of the species here mentioned, could have impressed the indentations as you have traced them. This tuft of tawny hair, too, is identical in character with that of the beast of Cuvier. But I cannot possibly comprehend the particulars of this frightful mystery. Besides, there were two voices heard in contention, and one of them was unquestionably the voice of a Frenchman."  
  
   "True; and you will remember an expression attributed almost unanimously, by the evidence, to this voice, --the expression, 'mon Dieu!' This, under the circumstances, has been justly characterized by one of the witnesses (Montani, the confectioner,) as an expression of remonstrance or expostulation. Upon these two words, therefore, I have mainly built my hopes of a full solution of the riddle. A Frenchman was cognizant of the murder. It is possible --indeed it is far more than probable --that he was innocent of all participation in the bloody transactions which took place. The Ourang-Outang may have escaped from him. He may have traced it to the chamber; but, under the agitating circumstances which ensued, he could never have re-captured it. It is still at large. I will not pursue these guesses --for I have no right to call them more --since the shades of reflection upon which they are based are scarcely of sufficient depth to be appreciable by my own intellect, and since I could not pretend to make them intelligible to the understanding of another. We will call them guesses then, and speak of them as such. If the Frenchman in question is indeed, as I suppose, innocent of this atrocity, this advertisement, which I left last night, upon our return home, at the office of 'Le Monde,' (a paper devoted to the shipping interest, and much sought by sailors,) will bring him to our residence."  
  
   He handed me a paper, and I read thus:  
  
   CAUGHT -- In the Bois de Boulogne, early in the morning of the ___ inst., (the morning of the murder,) a very large, tawny Ourang-Outang of the Bornese species. The owner, (who is ascertained to be a sailor, belonging to a Maltese vessel,) may have the animal again, upon identifying it satisfactorily, and paying a few charges arising from its capture and keeping. Call at No. ___ , Rue ___, Faubourg St. Germain --au troisiême.  
  
   "How was it possible," I asked, "that you should know the man to be a sailor, and belonging to a Maltese vessel?"  
  
   "I do not know it," said Dupin. "I am not sure of it. Here, however, is a small piece of ribbon, which from its form, and from its greasy appearance, has evidently been used in tying the hair in one of those long queues of which sailors are so fond. Moreover, this knot is one which few besides sailors can tie, and is peculiar to the Maltese. I picked the ribbon up at the foot of the lightning-rod. It could not have belonged to either of the deceased. Now if, after all, I am wrong in my induction from this ribbon, that the Frenchman was a sailor belonging to a Maltese vessel, still I can have done no harm in saying what I did in the advertisement. If I am in error, he will merely suppose that I have been misled by some circumstance into which he will not take the trouble to inquire. But if I am right, a great point is gained. Cognizant although innocent of the murder, the Frenchman will naturally hesitate about replying to the advertisement --about demanding the Ourang-Outang. He will reason thus: --'I am innocent; I am poor; my Ourang-Outang is of great value --to one in my circumstances a fortune of itself --why should I lose it through idle apprehensions of danger? Here it is, within my grasp. It was found in the Bois de Boulogne --at a vast distance from the scene of that butchery. How can it ever be suspected that a brute beast should have done the deed? The police are at fault --they have failed to procure the slightest clew. Should they even trace the animal, it would be impossible to prove me cognizant of the murder, or to implicate me in guilt on account of that cognizance. Above all, I am known. The advertiser designates me as the possessor of the beast. I am not sure to what limit his knowledge may extend. Should I avoid claiming a property of so great value, which it is known that I possess, I will render the animal at least, liable to suspicion. It is not my policy to attract attention either to myself or to the beast. I will answer the advertisement, get the Ourang-Outang, and keep it close until this matter has blown over.' "  
  
   At this moment we heard a step upon the stairs.  
  
   "Be ready," said Dupin, "with your pistols, but neither use them nor show them until at a signal from myself."  
  
   The front door of the house had been left open, and the visiter had entered, without ringing, and advanced several steps upon the staircase. Now, however, he seemed to hesitate. Presently we heard him descending. Dupin was moving quickly to the door, when we again heard him coming up. He did not turn back a second time, but stepped up with decision, and rapped at the door of our chamber.  


  
   "Come in," said Dupin, in a cheerful and hearty tone.  
  
   A man entered. He was a sailor, evidently, --a tall, stout, and muscular-looking person, with a certain dare-devil expression of countenance, not altogether unprepossessing. His face, greatly sunburnt, was more than half hidden by whisker and mustachio. He had with him a huge oaken cudgel, but appeared to be otherwise unarmed. He bowed awkwardly, and bade us "good evening," in French accents, which, although somewhat Neufchatelish, were still sufficiently indicative of a Parisian origin.  
  
   "Sit down, my friend," said Dupin. "I suppose you have called about the Ourang-Outang. Upon my word, I almost envy you the possession of him; a remarkably fine, and no doubt a very valuable animal. How old do you suppose him to be?"  
  
   The sailor drew a long breath, with the air of a man relieved of some intolerable burden, and then replied, in an assured tone:  
  
   "I have no way of telling --but he can't be more than four or five years old. Have you got him here?"  
  
   "Oh no; we had no conveniences for keeping him here. He is at a livery stable in the Rue Dubourg, just by. You can get him in the morning. Of course you are prepared to identify the property?"  
  
   "To be sure I am, sir."  
  
   "I shall be sorry to part with him," said Dupin.  
  
   "I don't mean that you should be at all this trouble for nothing, sir," said the man. "Couldn't expect it. Am very willing to pay a reward for the finding of the animal -- that is to say, any thing in reason."  
  
   "Well," replied my friend, "that is all very fair, to be sure. Let me think! --what should I have? Oh! I will tell you. My reward shall be this. You shall give me all the information in your power about these murders in the Rue Morgue."  
  
   Dupin said the last words in a very low tone, and very quietly. Just as quietly, too, he walked toward the door, locked it, and put the key in his pocket. He then drew a pistol from his bosom and placed it, without the least flurry, upon the table.  
  
   The sailor's face flushed up as if he were struggling with suffocation. He started to his feet and grasped his cudgel; but the next moment he fell back into his seat, trembling violently, and with the countenance of death itself. He spoke not a word. I pitied him from the bottom of my heart.  
  
   "My friend," said Dupin, in a kind tone, "you are alarming yourself unnecessarily --you are indeed. We mean you no harm whatever. I pledge you the honor of a gentleman, and of a Frenchman, that we intend you no injury. I perfectly well know that you are innocent of the atrocities in the Rue Morgue. It will not do, however, to deny that you are in some measure implicated in them. From what I have already said, you must know that I have had means of information about this matter --means of which you could never have dreamed. Now the thing stands thus. You have done nothing which you could have avoided --nothing, certainly, which renders you culpable. You were not even guilty of robbery, when you might have robbed with impunity. You have nothing to conceal. You have no reason for concealment. On the other hand, you are bound by every principle of honor to confess all you know. An innocent man is now imprisoned, charged with that crime of which you can point out the perpetrator."  
  
   The sailor had recovered his presence of mind, in a great measure, while Dupin uttered these words; but his original boldness of bearing was all gone.  
  
   "So help me God," said he, after a brief pause, "I will tell you all I know about this affair; --but I do not expect you to believe one half I say --I would be a fool indeed if I did. Still, I am innocent, and I will make a clean breast if I die for it."  
  
   What he stated was, in substance, this. He had lately made a voyage to the Indian Archipelago. A party, of which he formed one, landed at Borneo, and passed into the interior on an excursion of pleasure. Himself and a companion had captured the Ourang- Outang. This companion dying, the animal fell into his own exclusive possession. After great trouble, occasioned by the intractable ferocity of his captive during the home voyage, he at length succeeded in lodging it safely at his own residence in Paris, where, not to attract toward himself the unpleasant curiosity of his neighbors, he kept it carefully secluded, until such time as it should recover from a wound in the foot, received from a splinter on board ship. His ultimate design was to sell it.  
  
   Returning home from some sailors' frolic the night, or rather in the morning of the murder, he found the beast occupying his own bed-room, into which it had broken from a closet adjoining, where it had been, as was thought, securely confined. Razor in hand, and fully lathered, it was sitting before a looking-glass, attempting the operation of shaving, in which it had no doubt previously watched its master through the key-hole of the closet. Terrified at the sight of so dangerous a weapon in the possession of an animal so ferocious, and so well able to use it, the man, for some moments, was at a loss what to do. He had been accustomed, however, to quiet the creature, even in its fiercest moods, by the use of a whip, and to this he now resorted. Upon sight of it, the Ourang-Outang sprang at once through the door of the chamber, down the stairs, and thence, through a window, unfortunately open, into the street.  
  
    The Frenchman followed in despair; the ape, razor still in hand, occasionally stopping to look back and gesticulate at its pursuer, until the latter had nearly come up with it. It then again made off. In this manner the chase continued for a long time. The streets were profoundly quiet, as it was nearly three o'clock in the morning. In passing down an alley in the rear of the Rue Morgue, the fugitive's attention was arrested by a light gleaming from the open window of Madame L'Espanaye's chamber, in the fourth story of her house. Rushing to the building, it perceived the lightning-rod, clambered up with inconceivable agility, grasped the shutter, which was thrown fully back against the wall, and, by its means, swung itself directly upon the headboard of the bed. The whole feat did not occupy a minute. The shutter was kicked open again by the Ourang-Outang as it entered the room.  
  
    The sailor, in the meantime, was both rejoiced and perplexed. He had strong hopes of now recapturing the brute, as it could scarcely escape from the trap into which it had ventured, except by the rod, where it might be intercepted as it came down. On the other hand, there was much cause for anxiety as to what it might do in the house. This latter reflection urged the man still to follow the fugitive. A lightning-rod is ascended without difficulty, especially by a sailor; but, when he had arrived as high as the window, which lay far to his left, his career was stopped; the most that he could accomplish was to reach over so as to obtain a glimpse of the interior of the room. At this glimpse he nearly fell from his hold through excess of horror. Now it was that those hideous shrieks arose upon the night, which had startled from slumber the inmates of the Rue Morgue. Madame L'Espanaye and her daughter, habited in their night clothes, had apparently been occupied in arranging some papers in the iron chest already mentioned, which had been wheeled into the middle of the room. It was open, and its contents lay beside it on the floor. The victims must have been sitting with their backs toward the window; and, from the time elapsing between the ingress of the beast and the screams, it seems probable that it was not immediately perceived. The flapping-to of the shutter would naturally have been attributed to the wind.  
  
    As the sailor looked in, the gigantic animal had seized Madame L'Espanaye by the hair, (which was loose, as she had been combing it,) and was flourishing the razor about her face, in imitation of the motions of a barber. The daughter lay prostrate and motionless; she had swooned. The screams and struggles of the old lady (during which the hair was torn from her head) had the effect of changing the probably pacific purposes of the Ourang-Outang into those of wrath. With one determined sweep of its muscular arm it nearly severed her head from her body. The sight of blood inflamed its anger into phrenzy. Gnashing its teeth, and flashing fire from its eyes, it flew upon the body of the girl, and imbedded its fearful talons in her throat, retaining its grasp until she expired. Its wandering and wild glances fell at this moment upon the head of the bed, over which the face of its master, rigid with horror, was just discernible. The fury of the beast, who no doubt bore still in mind the dreaded whip, was instantly converted into fear. Conscious of having deserved punishment, it seemed desirous of concealing its bloody deeds, and skipped about the chamber in an agony of nervous agitation; throwing down and breaking the furniture as it moved, and dragging the bed from the bedstead. In conclusion, it seized first the corpse of the daughter, and thrust it up the chimney, as it was found; then that of the old lady, which it immediately hurled through the window headlong.  
  
    As the ape approached the casement with its mutilated burden, the sailor shrank aghast to the rod, and, rather gliding than clambering down it, hurried at once home --dreading the consequences of the butchery, and gladly abandoning, in his terror, all solicitude about the fate of the Ourang-Outang. The words heard by the party upon the staircase were the Frenchman's exclamations of horror and affright, commingled with the fiendish jabberings of the brute.  
  
    I have scarcely anything to add. The Ourang-Outang must have escaped from the chamber, by the rod, just before the breaking of the door. It must have closed the window as it passed through it. It was subsequently caught by the owner himself, who obtained for it a very large sum at the Jardin des Plantes. Le Bon was instantly released, upon our narration of the circumstances (with some comments from Dupin) at the bureau of the Prefect of Police. This functionary, however well disposed to my friend, could not altogether conceal his chagrin at the turn which affairs had taken, and was fain to indulge in a sarcasm or two, about the propriety of every person minding his own business.  
  
    "Let him talk," said Dupin, who had not thought it necessary to reply. "Let him discourse; it will ease his conscience. I am satisfied with having defeated him in his own castle. Nevertheless, that he failed in the solution of this mystery, is by no means that matter for wonder which he supposes it; for, in truth, our friend the Prefect is somewhat too cunning to be profound. In his wisdom is no stamen. It is all head and no body, like the pictures of the Goddess Laverna, -- or, at best, all head and shoulders, like a codfish. But he is a good creature after all. I like him especially for one master stroke of cant, by which he has attained his reputation for ingenuity. I mean the way he has 'de nier ce qui est, et d'expliquer ce qui n'est pas.' "*  
  
  
*Rousseau --Nouvelle Heloise.